function ImageCallback(obj, event)
% ImageCallback - Callback called by a MatlabServer object for generating
% an image of a Matlab figure as response
% 
% CALL:
%     ImageCallback(obj, event)
% 
% INPUT:
%     obj: 
%         handle to the MatlabServer object which triggered the callback
%     event: 
%         ServerEvent with query and response information
% 
% OUTPUT:
%     No output
%
%   Copyright 2006-2015 Modelit, www.modelit.nl

% It's good practice to always surround the callback with try catch
% and always return an answer to the client
try 

    HWIN = findobj('tag',mfilename);
    
    if isempty(HWIN) || ~ishandle(HWIN)
        HWIN = figure('tag',mfilename);
        membrane;
     %   colormap(randpick({'spring','summer','autumn','winter','hot','cool','bone','pink','copper','jet'}));
        shading interp;
    end

    % Generate the response
    [~, response] = fig2base64(HWIN, 'png');
    
    delete(HWIN);
        
    % Return response to the client
    sendResponse(event, response,...
        'contenttype', 'image/png')  % The MIME type 

catch me
    sendResponse(event, errorMessage(me.message),...
        'statuscode', 500,...        % Statuscode 500: Interval Server Error
        'contenttype', 'text/html')  % The MIME type 
end
%__________________________________________________________________________
function text = errorMessage(msg)
% errorMessage - Make an HTML error message
% 
% CALL:
%  text = errorMessage(msg)

text = {'<html><center>'
    sprintf('<h1 >%s</h1>',datestr(now))
    sprintf('<h2 style="color:red">%s</h2>',msg)
    '</center></html>'};

text = [text{:}];
