function server = startMatlabServer(port, callback)
% startMatlabServer - Start a server that listens to the specified port and
% triggers the specified callback when a request is made
% 
% CALL:
%     server = startMatlabServer(port, callback)
% 
% INPUT
%     port:
%         A port number to which the server is listening. This arguments
%         must correspond to one of the ports specified with the "port"
%         property in the web.xml script.
%    callback:
%       (Optional) A Matlab function which should be called when a request
%       is made 
% 
% OUTPUT:
%     server:
%         The MatlabServer object that has been created
%
%   Copyright 2006-2013 Modelit, www.modelit.nl

if nargin < 1
    error('Specify port e.g. 4444');
end

if nargin < 2
    callback = @HTMLCallback;
end

% Create a server on the specified port, port should be a port specified in
% the web.xml in the matlabserver directory in the Tomcat root
server = createMatlabServer(port);

% Set callback to be executed when server receives a request from client
set(server, 'ServerInvokedCallback', callback);

% Start serving
server.startServer;
