disp('This startup script sets the default path for the Modelit Webserver Toolbox')

% Note: this startup script was tested with Matlab 2013a /64

%Include required utilities in Matlab path
disp(sprintf('Including %s in Matlab path',fullfile(pwd,'utils')))
addpath(fullfile(pwd,'utils'))

%Include examples in Matlab path
disp(sprintf('Including %s in Matlab path',fullfile(pwd,'examples')))
addpath(fullfile(pwd,'examples'))

%check static path for MatlabServer.jar
spath=javaclasspath('-static');
f=find(~cellfun(@isempty,strfind(spath,'MatlabServer.jar')));
if ~isempty(f)
    %MatlabServer found on path
    disp(sprintf('Static path contains MatlabServer.jar at location "%s"',spath{f(1)}));
    disp('Assuming above settings are correct, the toolbox is ready for use.')
    disp('Exiting startup script');
    return
end

disp('MatlabServer.jar was not found on the static path');
 
%Find out the name that stores the static classpath
staticpathdeffile='javaclasspath.txt'; %for Matlab 2013a and up
try
    if verLessThan('matlab','8')
        %version 2012b or earlier ==> write classpath.txt
        staticpathdeffile='classpath.txt';
    end
catch
    %even older version (verLessThan not found) ==> write classpath.txt
    staticpathdeffile='classpath.txt';
end

disp(sprintf('You may need to create a file titled "%s" that defines the static path',fullfile(pwd,staticpathdeffile)));


drawnow

s=input('Do you want help with this? (y/n)','s');

if ~strncmpi(s,'y',1)
    disp('Exiting startup script');
    return
end

pth=input('Please enter the directory name that holds editClasspath.m and MatlabServer.jar\n','s');


if ~exist(pth,'dir')
    disp('Directory does not exist. To retry, rerun startup script.')
    disp('Exiting startup script');
    return
end

if ~exist(fullfile(pth,'editClasspath.m'),'file')
    disp('Directory does not contain editClasspath.m. To retry, rerun startup script.')
    disp('Exiting startup script');
    return
end

if ~exist(fullfile(pth,'MatlabServer.jar'),'file')
    disp('Directory does not contain MatlabServer.jar. To retry, rerun startup script.')
    disp('Exiting startup script');
    return
end

%run editClasspath from the specified location
addpath(pth)

disp('run editClasspath.m from specified location');
eval('editClasspath')
disp('The classpath has been specified. Restart Matlab for the settings to have effect.');
disp('Exiting startup script');
